@@ -8,22 +8,20 @@ from graia.saya.builtins.broadcast.schema import ListenerSchema
 
 from pony.orm import *
 
-from .databases import messageTables
-
+from . import tables
 
 saya = Saya.current()
 channel = Channel.current()
 
-@channel.use(ListenerSchema(
-    listening_events=[GroupMessage] # 填入你需要监听的事件
-))
+
+@channel.use(ListenerSchema(listening_events=[GroupMessage]  # 填入你需要监听的事件
+                            ))
 @db_session
 async def record(group: Group, member: Member, messageChain: MessageChain):
     if messageChain.has(Plain):
-        messageTables.GroupMessage(
-            groupId=str(group.id), 
+        tables.messageTables.GroupMessage(
+            groupId=str(group.id),
             dateTime=messageChain.getFirst(Source).time,
-            memberId=str(member.id), 
-            plain=messageChain.include(Plain).asDisplay()
-        )
+            memberId=str(member.id),
+            plain=messageChain.include(Plain).asDisplay())
         commit()
\ No newline at end of file
